package com.clicknect.android.sqlite;

import java.util.ArrayList;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.Toast;

import com.clicknect.android.sqlite.adapter.FriendsListViewAdapter;
import com.clicknect.android.sqlite.db.FriendsDB;
import com.clicknect.android.sqlite.entry.FriendEntry;

public class MainActivity extends Activity {

	// -- General ------------------------------------------
	private Context context;
	private ArrayList<FriendEntry> entries;
	private ListView listView;
	private FriendsListViewAdapter listViewAdapter;
	
	// -- Database -----------------------------------------
	private FriendsDB db;
	
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.layout_main);
        
        // Context
        context = this;
        
        // View matching
        listView = (ListView) findViewById(R.id.main_data_listview);
        
        // Initialize list view & adapter
        entries = new ArrayList<FriendEntry>();
    	listViewAdapter = new FriendsListViewAdapter(context, entries);
    	listView.setAdapter(listViewAdapter);
    	listViewAdapter.notifyDataSetChanged();        
        
    	// Initialize database
        db = new FriendsDB(context);
        selectAll();
        
        // Event
        listView.setOnItemClickListener(new AdapterView.OnItemClickListener() {
			@Override
			public void onItemClick(AdapterView<?> adapterView, View view, final int position, long which) {				
				AlertDialog.Builder fBuilder = new AlertDialog.Builder(context);
				fBuilder.setTitle(entries.get(position).getNickname()+"'s info");
				fBuilder.setIcon(getResources().getDrawable(R.drawable.ic_user));
				String fDetail = entries.get(position).getFname()+" "+entries.get(position).getLname()+"\n";
				fDetail += entries.get(position).getNickname()+" [#"+entries.get(position).getId()+"]\n";
				fDetail += "fb.com/"+entries.get(position).getFbID();
				fBuilder.setMessage(fDetail);
				fBuilder.setCancelable(true);
				fBuilder.setPositiveButton("Delete", new DialogInterface.OnClickListener() {
					@Override
					public void onClick(DialogInterface dialog, int which) {
						int nDeleted = db.deleteByID(entries.get(position).getId());
						if ( nDeleted != -1 ) {
							Toast.makeText(context, "Deleted "+nDeleted+" friend.", Toast.LENGTH_SHORT).show();
							selectAll();
						} else {
							Toast.makeText(context, "Unable to delete this friend.", Toast.LENGTH_SHORT).show();
						}
					}
				});
				fBuilder.setNeutralButton("Update", new DialogInterface.OnClickListener() {
					@Override
					public void onClick(DialogInterface dialog, int which) {
						dialog.dismiss();
					}
				});
				fBuilder.setNegativeButton("Dismiss", new DialogInterface.OnClickListener() {
					@Override
					public void onClick(DialogInterface dialog, int which) {
						dialog.dismiss();
					}
				});
				
				AlertDialog fAlert = fBuilder.create();
				fAlert.show();
			}
		});
    }
    
    public void selectAll() {
    	entries.clear();
        entries = db.selectAll();
        int nFriends = entries.size();
        if ( nFriends == 0 ) {
            Toast.makeText(context, "You don't have any friend.", Toast.LENGTH_SHORT).show();
        } else {
        	listViewAdapter.setEntries(entries);
        	listViewAdapter.notifyDataSetChanged();        	
        	Toast.makeText(context, "You have "+entries.size()+" friends.", Toast.LENGTH_SHORT).show();
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.layout_main, menu);
        return true;
    }
    
    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
    	switch ( item.getItemId() ) {
	    	case R.id.menu_refresh:
	    		selectAll();
	    		break;
	    		
	    	case R.id.menu_insert:
	    		View view = LayoutInflater.from(context).inflate(R.layout.layout_add_friend, null);
	    		final EditText eFname = (EditText) view.findViewById(R.id.add_friend_fname);
	    		final EditText eLname = (EditText) view.findViewById(R.id.add_friend_lname);
	    		final EditText eNickname = (EditText) view.findViewById(R.id.add_friend_nickname);
	    		final EditText eFbID = (EditText) view.findViewById(R.id.add_friend_fb_id);
	    		
	    		AlertDialog.Builder iBuilder = new AlertDialog.Builder(context);
	    		iBuilder.setTitle("Add new friend");
	    		iBuilder.setIcon(getResources().getDrawable(R.drawable.ic_user));
	    		iBuilder.setView(view);
	    		iBuilder.setNegativeButton("Save", new DialogInterface.OnClickListener() {
					@Override
					public void onClick(DialogInterface dialog, int which) {
						String fname = eFname.getText().toString().trim();
						String lname = eLname.getText().toString().trim();
						String nickname = eNickname.getText().toString().trim();
						String fbID = eFbID.getText().toString().trim();
						
						if ( fname.length() == 0 ) {
							Toast.makeText(context, "First name is required.", Toast.LENGTH_SHORT).show();
						} else if ( lname.length() == 0 ) {
							Toast.makeText(context, "Last name is required.", Toast.LENGTH_SHORT).show();
						} else if ( nickname.length() == 0 ) {
							Toast.makeText(context, "Nickname is required.", Toast.LENGTH_SHORT).show();
						} else if ( fbID.length() == 0 ) {
							Toast.makeText(context, "Facebook ID is required.", Toast.LENGTH_SHORT).show();
						} else {
				    		long id = db.insert(fbID, fname, lname, nickname);
				    		if ( id != -1 ) {
				    			Toast.makeText(context, "Added new friend [id#"+id+"]", Toast.LENGTH_SHORT).show();
				    			selectAll();
				    		} else {
				    			Toast.makeText(context, "Failed to add new friend.", Toast.LENGTH_SHORT).show();
				    		}							
						}
					}
				});
	    		iBuilder.setPositiveButton("Cancel", new DialogInterface.OnClickListener() {
					@Override
					public void onClick(DialogInterface dialog, int which) {
						dialog.dismiss();
					}
				});
	    		iBuilder.setCancelable(false);
	    		
	    		AlertDialog iAlert = iBuilder.create();
	    		iAlert.show();
	    		break;
	    		
	    	case R.id.menu_clear:
	    		if ( entries.size() != 0 ) {
	    			AlertDialog.Builder builder = new AlertDialog.Builder(context);
	    			builder.setIcon(getResources().getDrawable(R.drawable.ic_user));
	    			builder.setTitle("Clear Friends");
	    			builder.setMessage("Do you want to clear all?");
	    			builder.setPositiveButton("Yes", new DialogInterface.OnClickListener() {
						@Override
						public void onClick(DialogInterface dialog, int which) {
							db.deleteAll();
							
			    			Toast.makeText(context, "Cleared all friends.", Toast.LENGTH_SHORT).show();
			    			
			    			entries.clear();
			    			listViewAdapter.notifyDataSetChanged();
						}
					});
	    			builder.setNegativeButton("No", new DialogInterface.OnClickListener() {
						@Override
						public void onClick(DialogInterface dialog, int which) {
							dialog.dismiss();
						}
					});
	    			builder.setCancelable(false);
	    			
	    			AlertDialog alert = builder.create();
	    			alert.show();
	    		} else {
	    			Toast.makeText(context, "You don't have any friend.", Toast.LENGTH_SHORT).show();
	    		}
	    		break;
    	}
    	return super.onOptionsItemSelected(item);
    }
    
}
